@@ -3,6 +3,7 @@ Salt package
 """
 
 import importlib
+import os
 import sys
 import warnings
 
@@ -26,18 +27,63 @@ class TornadoImporter:
                 return self
         return None
 
-    def load_module(self, name):
+    def create_module(self, spec):
         if USE_VENDORED_TORNADO:
-            mod = importlib.import_module("salt.ext.{}".format(name))
+            mod = importlib.import_module("salt.ext.{}".format(spec.name))
         else:
             # Remove 'salt.ext.' from the module
-            mod = importlib.import_module(name[9:])
-        sys.modules[name] = mod
+            mod = importlib.import_module(spec.name[9:])
+        sys.modules[spec.name] = mod
         return mod
 
+    def exec_module(self, module):
+        return None
+
+
+class NaclImporter:
+    """
+    Import hook to force PyNaCl to perform dlopen on libsodium with the
+    RTLD_DEEPBIND flag. This is to work around an issue where pyzmq does a dlopen
+    with RTLD_GLOBAL which then causes calls to libsodium to resolve to
+    tweetnacl when it's been bundled with pyzmq.
+
+    See:  https://github.com/zeromq/pyzmq/issues/1878
+    """
+
+    loading = False
+
+    def find_module(self, module_name, package_path=None):
+        if not NaclImporter.loading and module_name.startswith("nacl"):
+            NaclImporter.loading = True
+            return self
+        return None
+
+    def create_module(self, spec):
+        dlopen = hasattr(sys, "getdlopenflags")
+        if dlopen:
+            dlflags = sys.getdlopenflags()
+            # Use RTDL_DEEPBIND in case pyzmq was compiled with ZMQ_USE_TWEETNACL. This is
+            # needed because pyzmq imports libzmq with RTLD_GLOBAL.
+            if hasattr(os, "RTLD_DEEPBIND"):
+                flags = os.RTLD_DEEPBIND | dlflags
+            else:
+                flags = dlflags
+            sys.setdlopenflags(flags)
+        try:
+            mod = importlib.import_module(spec.name)
+        finally:
+            if dlopen:
+                sys.setdlopenflags(dlflags)
+        NaclImporter.loading = False
+        sys.modules[spec.name] = mod
+        return mod
+
+    def exec_module(self, module):
+        return None
+
 
 # Try our importer first
-sys.meta_path = [TornadoImporter()] + sys.meta_path
+sys.meta_path = [TornadoImporter(), NaclImporter()] + sys.meta_path
 
 
 # All salt related deprecation warnings should be shown once each!
@@ -46,7 +92,8 @@ warnings.filterwarnings(
     "",  # No deprecation message match
     DeprecationWarning,  # This filter is for DeprecationWarnings
     r"^(salt|salt\.(.*))$",  # Match module(s) 'salt' and 'salt.<whatever>'
-    append=True,
+    # Do *NOT* add append=True here - if we do, salt's DeprecationWarnings will
+    # never show up
 )
 
 # Filter the backports package UserWarning about being re-imported
@@ -57,6 +104,20 @@ warnings.filterwarnings(
     append=True,
 )
 
+# Filter the setuptools UserWarning until we stop relying on distutils
+warnings.filterwarnings(
+    "ignore",
+    message="Setuptools is replacing distutils.",
+    category=UserWarning,
+    module="_distutils_hack",
+)
+
+warnings.filterwarnings(
+    "ignore",
+    message="invalid escape sequence.*",
+    category=DeprecationWarning,
+)
+
 
 def __define_global_system_encoding_variable__():
     import sys
@@ -79,14 +140,14 @@ def __define_global_system_encoding_variable__():
         import locale
 
         try:
-            encoding = locale.getdefaultlocale()[-1]
-        except ValueError:
-            # A bad locale setting was most likely found:
-            #   https://github.com/saltstack/salt/issues/26063
-            pass
+            encoding = locale.getencoding()
+        except AttributeError:
+            # Python < 3.11
+            encoding = locale.getpreferredencoding(do_setlocale=True)
 
         # This is now garbage collectable
         del locale
+
         if not encoding:
             # This is most likely ascii which is not the best but we were
             # unable to find a better encoding. If this fails, we fall all
@@ -120,5 +181,9 @@ __define_global_system_encoding_variable__()
 # This is now garbage collectable
 del __define_global_system_encoding_variable__
 
-# Import Salt's logging machinery
-import salt._logging.impl  # isort:skip  pylint: disable=unused-import
+# Make sure Salt's logging tweaks are always present
+# DO NOT MOVE THIS IMPORT
+# pylint: disable=unused-import
+import salt._logging  # isort:skip
+
+# pylint: enable=unused-import
