@@ -3,6 +3,7 @@ A simple beacon to watch journald for specific entries
 """
 import logging
 
+import salt.utils.beacons
 import salt.utils.data
 
 try:
@@ -21,7 +22,9 @@ __virtualname__ = "journald"
 def __virtual__():
     if HAS_SYSTEMD:
         return __virtualname__
-    return False
+    err_msg = "systemd library is missing."
+    log.error("Unable to load %s beacon: %s", __virtualname__, err_msg)
+    return False, err_msg
 
 
 def _get_journal():
@@ -45,17 +48,14 @@ def validate(config):
     if not isinstance(config, list):
         return (False, "Configuration for journald beacon must be a list.")
     else:
-        _config = {}
-        list(map(_config.update, config))
+        config = salt.utils.beacons.list_to_dict(config)
 
-        for name in _config.get("services", {}):
-            if not isinstance(_config["services"][name], dict):
+        for name in config.get("services", {}):
+            if not isinstance(config["services"][name], dict):
                 return (
                     False,
-                    (
-                        "Services configuration for journald beacon "
-                        "must be a list of dictionaries."
-                    ),
+                    "Services configuration for journald beacon must be a list of"
+                    " dictionaries.",
                 )
     return True, "Valid beacon configuration"
 
@@ -79,23 +79,22 @@ def beacon(config):
     ret = []
     journal = _get_journal()
 
-    _config = {}
-    list(map(_config.update, config))
+    config = salt.utils.beacons.list_to_dict(config)
 
     while True:
         cur = journal.get_next()
         if not cur:
             break
 
-        for name in _config.get("services", {}):
+        for name in config.get("services", {}):
             n_flag = 0
-            for key in _config["services"][name]:
+            for key in config["services"][name]:
                 if isinstance(key, str):
                     key = salt.utils.data.decode(key)
                 if key in cur:
-                    if _config["services"][name][key] == cur[key]:
+                    if config["services"][name][key] == cur[key]:
                         n_flag += 1
-            if n_flag == len(_config["services"][name]):
+            if n_flag == len(config["services"][name]):
                 # Match!
                 sub = salt.utils.data.simple_types_filter(cur)
                 sub.update({"tag": name})
