@@ -19,6 +19,8 @@ Beacon that fires events on image import/delete.
 """
 import logging
 
+import salt.utils.beacons
+
 __virtualname__ = "imgadm"
 
 IMGADM_STATE = {
@@ -36,12 +38,9 @@ def __virtual__():
     if "imgadm.list" in __salt__:
         return True
     else:
-        return (
-            False,
-            "{} beacon can only be loaded on SmartOS compute nodes".format(
-                __virtualname__
-            ),
-        )
+        err_msg = "Only available on SmartOS compute nodes."
+        log.error("Unable to load %s beacon: %s", __virtualname__, err_msg)
+        return False, err_msg
 
 
 def validate(config):
@@ -71,10 +70,9 @@ def beacon(config):
     if IMGADM_STATE["first_run"]:
         log.info("Applying configuration for imgadm beacon")
 
-        _config = {}
-        list(map(_config.update, config))
+        config = salt.utils.beacons.list_to_dict(config)
 
-        if "startup_import_event" not in _config or not _config["startup_import_event"]:
+        if "startup_import_event" not in config or not config["startup_import_event"]:
             IMGADM_STATE["images"] = current_images
 
     # NOTE: import events
@@ -107,6 +105,3 @@ def beacon(config):
         IMGADM_STATE["first_run"] = False
 
     return ret
-
-
-# vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4
