@@ -17,10 +17,18 @@ import salt.utils.vt
 
 log = logging.getLogger(__name__)
 
-SSH_PASSWORD_PROMPT_RE = re.compile(r"(?:.*)[Pp]assword(?: for .*)?:", re.M)
+SSH_PASSWORD_PROMPT_RE = re.compile(r"(?:.*)[Pp]assword(?: for .*)?:\s*$", re.M)
 KEY_VALID_RE = re.compile(r".*\(yes\/no\).*")
 SSH_PRIVATE_KEY_PASSWORD_PROMPT_RE = re.compile(r"Enter passphrase for key", re.M)
 
+# sudo prompt is used to recognize sudo prompting for a password and should
+# therefore be fairly recognizable and unique
+SUDO_PROMPT = "[salt:sudo:d11bd4221135c33324a6bdc09674146fbfdf519989847491e34a689369bbce23]passwd:"
+SUDO_PROMPT_RE = re.compile(
+    r"\[salt:sudo:d11bd4221135c33324a6bdc09674146fbfdf519989847491e34a689369bbce23\]passwd:",
+    re.M,
+)
+
 # Keep these in sync with ./__init__.py
 RSTR = "_edbc7885e4f9aac9b83b35999b68d015148caf467b78fa39c05f669c0ff89878"
 RSTR_RE = re.compile(r"(?:^|\r?\n)" + RSTR + r"(?:\r?\n|$)")
@@ -268,7 +276,9 @@ class Shell:
         """
         try:
             proc = salt.utils.nb_popen.NonBlockingPopen(
-                self._split_cmd(cmd), stderr=subprocess.PIPE, stdout=subprocess.PIPE,
+                self._split_cmd(cmd),
+                stderr=subprocess.PIPE,
+                stdout=subprocess.PIPE,
             )
             while True:
                 time.sleep(0.1)
@@ -368,12 +378,16 @@ class Shell:
         if not cmd:
             return "", "No command or passphrase", 245
 
+        log_sanitize = None
+        if self.passwd:
+            log_sanitize = self.passwd
         term = salt.utils.vt.Terminal(
             self._split_cmd(cmd),
             log_stdout=True,
             log_stdout_level="trace",
             log_stderr=True,
             log_stderr_level="trace",
+            log_sanitize=log_sanitize,
             stream_stdout=False,
             stream_stderr=False,
         )
@@ -387,11 +401,15 @@ class Shell:
             while term.has_unread_data:
                 stdout, stderr = term.recv()
                 if stdout:
+                    if self.passwd:
+                        stdout = stdout.replace(self.passwd, ("*" * 6))
                     ret_stdout += stdout
                     buff = old_stdout + stdout
                 else:
                     buff = stdout
                 if stderr:
+                    if self.passwd:
+                        stderr = stderr.replace(self.passwd, ("*" * 6))
                     ret_stderr += stderr
                 if buff and RSTR_RE.search(buff):
                     # We're getting results back, don't try to send passwords
@@ -424,9 +442,15 @@ class Shell:
                         ret_stdout = (
                             "The host key needs to be accepted, to "
                             "auto accept run salt-ssh with the -i "
-                            "flag:\n{}"
-                        ).format(stdout)
+                            "flag:\n{}".format(stdout)
+                        )
                         return ret_stdout, "", 254
+                elif buff and SUDO_PROMPT_RE.search(buff):
+                    if not self.passwd:
+                        return "", "Sudo password is required but not provided", 254
+                    else:
+                        term.sendline(self.passwd)
+                        continue
                 elif buff and buff.endswith("_||ext_mods||_"):
                     mods_raw = (
                         salt.utils.json.dumps(self.mods, separators=(",", ":"))
