@@ -9,15 +9,16 @@ import logging
 import os
 import shutil
 import string
+import time
 import urllib.error
 import urllib.parse
 
+import salt.channel.client
 import salt.client
 import salt.crypt
 import salt.fileserver
 import salt.loader
 import salt.payload
-import salt.transport.client
 import salt.utils.atomicfile
 import salt.utils.data
 import salt.utils.files
@@ -31,7 +32,7 @@ import salt.utils.templates
 import salt.utils.url
 import salt.utils.verify
 import salt.utils.versions
-from salt.exceptions import CommandExecutionError, MinionError
+from salt.exceptions import CommandExecutionError, MinionError, SaltClientError
 from salt.ext.tornado.httputil import (
     HTTPHeaders,
     HTTPInputError,
@@ -84,7 +85,6 @@ class Client:
     def __init__(self, opts):
         self.opts = opts
         self.utils = salt.loader.utils(self.opts)
-        self.serial = salt.payload.Serial(self.opts)
 
     # Add __setstate__ and __getstate__ so that the object may be
     # deep copied. It normally can't be deep copied because its
@@ -172,7 +172,13 @@ class Client:
         raise NotImplementedError
 
     def cache_file(
-        self, path, saltenv="base", cachedir=None, source_hash=None, verify_ssl=True
+        self,
+        path,
+        saltenv="base",
+        cachedir=None,
+        source_hash=None,
+        verify_ssl=True,
+        use_etag=False,
     ):
         """
         Pull a file down from the file server and store it in the minion
@@ -186,6 +192,7 @@ class Client:
             cachedir=cachedir,
             source_hash=source_hash,
             verify_ssl=verify_ssl,
+            use_etag=use_etag,
         )
 
     def cache_files(self, paths, saltenv="base", cachedir=None):
@@ -466,6 +473,7 @@ class Client:
         cachedir=None,
         source_hash=None,
         verify_ssl=True,
+        use_etag=False,
     ):
         """
         Get a single file from a URL.
@@ -643,6 +651,7 @@ class Client:
             fixed_url = url
 
         destfp = None
+        dest_etag = "{}.etag".format(dest)
         try:
             # Tornado calls streaming_callback on redirect response bodies.
             # But we need streaming to support fetching large files (> RAM
@@ -670,10 +679,16 @@ class Client:
             #   False to signify that we are done parsing.
             #
             # write_body[2] is where the encoding will be stored
-            write_body = [None, False, None]
+            #
+            # write_body[3] is where the etag will be stored if use_etag is
+            #   enabled. This allows us to iterate over the headers until
+            #   both content encoding and etag are found.
+            write_body = [None, False, None, None]
 
             def on_header(hdr):
-                if write_body[1] is not False and write_body[2] is None:
+                if write_body[1] is not False and (
+                    write_body[2] is None or (use_etag and write_body[3] is None)
+                ):
                     if not hdr.strip() and "Content-Type" not in write_body[1]:
                         # If write_body[0] is True, then we are not following a
                         # redirect (initial response was a 200 OK). So there is
@@ -683,17 +698,32 @@ class Client:
                             # write_body[0] so that we properly follow it.
                             write_body[0] = None
                         # We don't need the HTTPHeaders object anymore
-                        write_body[1] = False
+                        if not use_etag or write_body[3]:
+                            write_body[1] = False
                         return
                     # Try to find out what content type encoding is used if
                     # this is a text file
                     write_body[1].parse_line(hdr)  # pylint: disable=no-member
-                    if "Content-Type" in write_body[1]:
+                    # Case insensitive Etag header checking below. Don't break case
+                    # insensitivity unless you really want to mess with people's heads
+                    # in the tests. Note: http.server and apache2 use "Etag" and nginx
+                    # uses "ETag" as the header key. Yay standards!
+                    if use_etag and "etag" in map(str.lower, write_body[1]):
+                        etag = write_body[3] = [
+                            val
+                            for key, val in write_body[1].items()
+                            if key.lower() == "etag"
+                        ][0]
+                        with salt.utils.files.fopen(dest_etag, "w") as etagfp:
+                            etag = etagfp.write(etag)
+                    elif "Content-Type" in write_body[1]:
                         content_type = write_body[1].get(
                             "Content-Type"
                         )  # pylint: disable=no-member
                         if not content_type.startswith("text"):
-                            write_body[1] = write_body[2] = False
+                            write_body[2] = False
+                            if not use_etag or write_body[3]:
+                                write_body[1] = False
                         else:
                             encoding = "utf-8"
                             fields = content_type.split(";")
@@ -702,7 +732,8 @@ class Client:
                                     encoding = field.split("encoding=")[-1]
                             write_body[2] = encoding
                             # We have found our encoding. Stop processing headers.
-                            write_body[1] = False
+                            if not use_etag or write_body[3]:
+                                write_body[1] = False
 
                         # If write_body[0] is False, this means that this
                         # header is a 30x redirect, so we need to reset
@@ -745,6 +776,14 @@ class Client:
                     if write_body[0]:
                         destfp.write(chunk)
 
+            # ETag is only used for refetch. Cached file and previous ETag
+            # should be present for verification.
+            header_dict = {}
+            if use_etag and os.path.exists(dest_etag) and os.path.exists(dest):
+                with salt.utils.files.fopen(dest_etag, "r") as etagfp:
+                    etag = etagfp.read().replace("\n", "").strip()
+                header_dict["If-None-Match"] = etag
+
             query = salt.utils.http.query(
                 fixed_url,
                 stream=True,
@@ -754,10 +793,22 @@ class Client:
                 password=url_data.password,
                 opts=self.opts,
                 verify_ssl=verify_ssl,
-                **get_kwargs
+                header_dict=header_dict,
+                **get_kwargs,
             )
+
+            # 304 Not Modified is returned when If-None-Match header
+            # matches server ETag for requested file.
+            if use_etag and query.get("status") == 304:
+                if not no_cache:
+                    destfp.close()
+                    destfp = None
+                    os.remove(dest_tmp)
+                return dest
             if "handle" not in query:
-                raise MinionError("Error: {} reading {}".format(query["error"], url))
+                raise MinionError(
+                    "Error: {} reading {}".format(query["error"], url_data.path)
+                )
             if no_cache:
                 if write_body[2]:
                     return "".join(result)
@@ -772,7 +823,7 @@ class Client:
                 "HTTP error {0} reading {1}: {3}".format(
                     exc.code,
                     url,
-                    *http.server.BaseHTTPRequestHandler.responses[exc.code]
+                    *http.server.BaseHTTPRequestHandler.responses[exc.code],
                 )
             )
         except urllib.error.URLError as exc:
@@ -789,7 +840,7 @@ class Client:
         makedirs=False,
         saltenv="base",
         cachedir=None,
-        **kwargs
+        **kwargs,
     ):
         """
         Cache a file then process it as a template
@@ -799,7 +850,6 @@ class Client:
             kwargs.pop("env")
 
         kwargs["saltenv"] = saltenv
-        url_data = urllib.parse.urlparse(url)
         sfn = self.cache_file(url, saltenv, cachedir=cachedir)
         if not sfn or not os.path.exists(sfn):
             return ""
@@ -842,6 +892,15 @@ class Client:
 
         # Strip user:pass from URLs
         netloc = netloc.split("@")[-1]
+        try:
+            if url_data.port:
+                # Remove : from path
+                netloc = netloc.replace(":", "")
+        except ValueError:
+            # On Windows urllib raises a ValueError
+            # when using a file:// source and trying
+            # to access the port attribute.
+            pass
 
         if cachedir is None:
             cachedir = self.opts["cachedir"]
@@ -1071,7 +1130,7 @@ class RemoteClient(Client):
     def __init__(self, opts):
         Client.__init__(self, opts)
         self._closing = False
-        self.channel = salt.transport.client.ReqChannel.factory(self.opts)
+        self.channel = salt.channel.client.ReqChannel.factory(self.opts)
         if hasattr(self.channel, "auth"):
             self.auth = self.channel.auth
         else:
@@ -1084,14 +1143,20 @@ class RemoteClient(Client):
         # Close the previous channel
         self.channel.close()
         # Instantiate a new one
-        self.channel = salt.transport.client.ReqChannel.factory(self.opts)
+        self.channel = salt.channel.client.ReqChannel.factory(self.opts)
         return self.channel
 
-    # pylint: disable=no-dunder-del
-    def __del__(self):
-        self.destroy()
-
-    # pylint: enable=no-dunder-del
+    def _channel_send(self, load, raw=False):
+        start = time.monotonic()
+        try:
+            return self.channel.send(
+                load,
+                raw=raw,
+            )
+        except salt.exceptions.SaltReqTimeoutError:
+            raise SaltClientError(
+                f"File client timed out after {int(time.time() - start)}"
+            )
 
     def destroy(self):
         if self._closing:
@@ -1121,13 +1186,8 @@ class RemoteClient(Client):
 
         if not salt.utils.platform.is_windows():
             hash_server, stat_server = self.hash_and_stat_file(path, saltenv)
-            try:
-                mode_server = stat_server[0]
-            except (IndexError, TypeError):
-                mode_server = None
         else:
             hash_server = self.hash_file(path, saltenv)
-            mode_server = None
 
         # Check if file exists on server, before creating files and
         # directories
@@ -1139,7 +1199,7 @@ class RemoteClient(Client):
         if dest is not None and (os.path.isdir(dest) or dest.endswith(("/", "\\"))):
             dest = os.path.join(dest, os.path.basename(path))
             log.debug(
-                "In saltenv '%s', '%s' is a directory. Changing dest to " "'%s'",
+                "In saltenv '%s', '%s' is a directory. Changing dest to '%s'",
                 saltenv,
                 os.path.dirname(dest),
                 dest,
@@ -1152,7 +1212,7 @@ class RemoteClient(Client):
             rel_path = self._check_proto(path)
 
             log.debug(
-                "In saltenv '%s', looking at rel_path '%s' to resolve " "'%s'",
+                "In saltenv '%s', looking at rel_path '%s' to resolve '%s'",
                 saltenv,
                 rel_path,
                 path,
@@ -1161,7 +1221,7 @@ class RemoteClient(Client):
                 dest2check = cache_dest
 
         log.debug(
-            "In saltenv '%s', ** considering ** path '%s' to resolve " "'%s'",
+            "In saltenv '%s', ** considering ** path '%s' to resolve '%s'",
             saltenv,
             dest2check,
             path,
@@ -1170,13 +1230,8 @@ class RemoteClient(Client):
         if dest2check and os.path.isfile(dest2check):
             if not salt.utils.platform.is_windows():
                 hash_local, stat_local = self.hash_and_stat_file(dest2check, saltenv)
-                try:
-                    mode_local = stat_local[0]
-                except (IndexError, TypeError):
-                    mode_local = None
             else:
                 hash_local = self.hash_file(dest2check, saltenv)
-                mode_local = None
 
             if hash_local == hash_server:
                 return dest2check
@@ -1217,7 +1272,10 @@ class RemoteClient(Client):
                 load["loc"] = 0
             else:
                 load["loc"] = fn_.tell()
-            data = self.channel.send(load, raw=True)
+            data = self._channel_send(
+                load,
+                raw=True,
+            )
             # Sometimes the source is local (eg when using
             # 'salt.fileserver.FSChan'), in which case the keys are
             # already strings. Sometimes the source is remote, in which
@@ -1310,28 +1368,36 @@ class RemoteClient(Client):
         List the files on the master
         """
         load = {"saltenv": saltenv, "prefix": prefix, "cmd": "_file_list"}
-        return self.channel.send(load)
+        return self._channel_send(
+            load,
+        )
 
     def file_list_emptydirs(self, saltenv="base", prefix=""):
         """
         List the empty dirs on the master
         """
         load = {"saltenv": saltenv, "prefix": prefix, "cmd": "_file_list_emptydirs"}
-        return self.channel.send(load)
+        return self._channel_send(
+            load,
+        )
 
     def dir_list(self, saltenv="base", prefix=""):
         """
         List the dirs on the master
         """
         load = {"saltenv": saltenv, "prefix": prefix, "cmd": "_dir_list"}
-        return self.channel.send(load)
+        return self._channel_send(
+            load,
+        )
 
     def symlink_list(self, saltenv="base", prefix=""):
         """
         List symlinked files and dirs on the master
         """
         load = {"saltenv": saltenv, "prefix": prefix, "cmd": "_symlink_list"}
-        return self.channel.send(load)
+        return self._channel_send(
+            load,
+        )
 
     def __hash_and_stat_file(self, path, saltenv="base"):
         """
@@ -1352,7 +1418,9 @@ class RemoteClient(Client):
                 ret["hash_type"] = hash_type
                 return ret
         load = {"path": path, "saltenv": saltenv, "cmd": "_file_hash"}
-        return self.channel.send(load)
+        return self._channel_send(
+            load,
+        )
 
     def hash_file(self, path, saltenv="base"):
         """
@@ -1379,7 +1447,9 @@ class RemoteClient(Client):
                 except Exception:  # pylint: disable=broad-except
                     return hash_result, None
         load = {"path": path, "saltenv": saltenv, "cmd": "_file_find"}
-        fnd = self.channel.send(load)
+        fnd = self._channel_send(
+            load,
+        )
         try:
             stat_result = fnd.get("stat")
         except AttributeError:
@@ -1391,21 +1461,27 @@ class RemoteClient(Client):
         Return a list of the files in the file server's specified environment
         """
         load = {"saltenv": saltenv, "cmd": "_file_list"}
-        return self.channel.send(load)
+        return self._channel_send(
+            load,
+        )
 
     def envs(self):
         """
         Return a list of available environments
         """
         load = {"cmd": "_file_envs"}
-        return self.channel.send(load)
+        return self._channel_send(
+            load,
+        )
 
     def master_opts(self):
         """
         Return the master opts data
         """
         load = {"cmd": "_master_opts"}
-        return self.channel.send(load)
+        return self._channel_send(
+            load,
+        )
 
     def master_tops(self):
         """
@@ -1414,7 +1490,15 @@ class RemoteClient(Client):
         load = {"cmd": "_master_tops", "id": self.opts["id"], "opts": self.opts}
         if self.auth:
             load["tok"] = self.auth.gen_token(b"salt")
-        return self.channel.send(load)
+        return self._channel_send(
+            load,
+        )
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *args):
+        self.destroy()
 
 
 class FSClient(RemoteClient):
