@@ -96,7 +96,7 @@ def _add(app, endpoint, payload):
     try:
         return getattr(getattr(nb, app), endpoint).create(**payload)
     except pynetbox.RequestError as e:
-        log.error("{}, {}, {}".format(e.req.request.headers, e.request_body, e.error))
+        log.error("%s, %s, %s", e.req.request.headers, e.request_body, e.error)
         return False
 
 
@@ -376,7 +376,7 @@ def create_device(name, role, model, manufacturer, site):
 
         status = {"label": "Active", "value": 1}
     except pynetbox.RequestError as e:
-        log.error("{}, {}, {}".format(e.req.request.headers, e.request_body, e.error))
+        log.error("%s, %s, %s", e.req.request.headers, e.request_body, e.error)
         return False
 
     payload = {
@@ -419,7 +419,7 @@ def update_device(name, **kwargs):
         nb_device.save()
         return {"dcim": {"devices": kwargs}}
     except pynetbox.RequestError as e:
-        log.error("{}, {}, {}".format(e.req.request.headers, e.request_body, e.error))
+        log.error("%s, %s, %s", e.req.request.headers, e.request_body, e.error)
         return False
 
 
@@ -558,7 +558,7 @@ def openconfig_interfaces(device_name=None):
     .. versionadded:: 2019.2.0
 
     Return a dictionary structured as standardised in the
-    `openconfig-interfaces <http://ops.openconfig.net/branches/master/openconfig-interfaces.html>`_
+    `openconfig-interfaces <http://ops.openconfig.net/branches/models/master/openconfig-interfaces.html>`_
     YANG model, containing physical and configuration data available in Netbox,
     e.g., IP addresses, MTU, enabled / disabled, etc.
 
@@ -641,7 +641,7 @@ def openconfig_lacp(device_name=None):
     .. versionadded:: 2019.2.0
 
     Return a dictionary structured as standardised in the
-    `openconfig-lacp <http://ops.openconfig.net/branches/master/openconfig-lacp.html>`_
+    `openconfig-lacp <http://ops.openconfig.net/branches/models/master/openconfig-lacp.html>`_
     YANG model, with configuration data for Link Aggregation Control Protocol
     (LACP) for aggregate interfaces.
 
@@ -649,8 +649,8 @@ def openconfig_lacp(device_name=None):
         The ``interval`` and ``lacp_mode`` keys have the values set as ``SLOW``
         and ``ACTIVE`` respectively, as this data is not currently available
         in Netbox, therefore defaulting to the values defined in the standard.
-        See `interval <http://ops.openconfig.net/branches/master/docs/openconfig-lacp.html#lacp-interfaces-interface-config-interval>`_
-        and `lacp-mode <http://ops.openconfig.net/branches/master/docs/openconfig-lacp.html#lacp-interfaces-interface-config-lacp-mode>`_
+        See `interval <http://ops.openconfig.net/branches/models/master/docs/openconfig-lacp.html#lacp-interfaces-interface-config-interval>`_
+        and `lacp-mode <http://ops.openconfig.net/branches/models/master/docs/openconfig-lacp.html#lacp-interfaces-interface-config-lacp-mode>`_
         for further details.
 
     device_name: ``None``
@@ -802,9 +802,7 @@ def update_interface(device_name, interface_name, **kwargs):
             nb_interface.save()
             return {"dcim": {"interfaces": {nb_interface.id: dict(nb_interface)}}}
         except pynetbox.RequestError as e:
-            log.error(
-                "{}, {}, {}".format(e.req.request.headers, e.request_body, e.error)
-            )
+            log.error("%s, %s, %s", e.req.request.headers, e.request_body, e.error)
             return False
 
 
