@@ -1,13 +1,9 @@
-# -*- coding: utf-8 -*-
 """
 Return data to local job cache
 
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 import bisect
-
-# Import python libs
 import errno
 import glob
 import logging
@@ -16,20 +12,15 @@ import shutil
 import time
 
 import salt.exceptions
-
-# Import salt libs
 import salt.payload
 import salt.utils.atomicfile
 import salt.utils.files
 import salt.utils.jid
+import salt.utils.job
 import salt.utils.minions
 import salt.utils.msgpack
 import salt.utils.stringutils
 
-# Import 3rd-party libs
-from salt.ext import six
-from salt.ext.six.moves import range  # pylint: disable=import-error,redefined-builtin
-
 log = logging.getLogger(__name__)
 
 # load is the published job
@@ -59,7 +50,6 @@ def _walk_through(job_dir):
     """
     Walk though the jid dir and look for jobs
     """
-    serial = salt.payload.Serial(__opts__)
 
     for top in os.listdir(job_dir):
         t_path = os.path.join(job_dir, top)
@@ -75,7 +65,7 @@ def _walk_through(job_dir):
 
             with salt.utils.files.fopen(load_path, "rb") as rfh:
                 try:
-                    job = serial.load(rfh)
+                    job = salt.payload.load(rfh)
                 except Exception:  # pylint: disable=broad-except
                     log.exception("Failed to deserialize %s", load_path)
                     continue
@@ -99,7 +89,7 @@ def prep_jid(nocache=False, passed_jid=None, recurse_count=0):
     So do what you have to do to make sure that stays the case
     """
     if recurse_count >= 5:
-        err = "prep_jid could not store a jid after {0} tries.".format(recurse_count)
+        err = "prep_jid could not store a jid after {} tries.".format(recurse_count)
         log.error(err)
         raise salt.exceptions.SaltCacheError(err)
     if passed_jid is None:  # this can be a None or an empty string.
@@ -125,7 +115,7 @@ def prep_jid(nocache=False, passed_jid=None, recurse_count=0):
         if nocache:
             with salt.utils.files.fopen(os.path.join(jid_dir, "nocache"), "wb+"):
                 pass
-    except IOError:
+    except OSError:
         log.warning("Could not write out jid file for job %s. Retrying.", jid)
         time.sleep(0.1)
         return prep_jid(
@@ -139,7 +129,6 @@ def returner(load):
     """
     Return data to the local job cache
     """
-    serial = salt.payload.Serial(__opts__)
 
     # if a minion is returning a standalone job, get a jobid
     if load["jid"] == "req":
@@ -171,17 +160,15 @@ def returner(load):
             return False
         raise
 
-    serial.dump(
-        dict(
-            (key, load[key]) for key in ["return", "retcode", "success"] if key in load
-        ),
+    salt.payload.dump(
+        {key: load[key] for key in ["return", "retcode", "success"] if key in load},
         # Use atomic open here to avoid the file being read before it's
         # completely written to. Refs #1935
         salt.utils.atomicfile.atomic_open(os.path.join(hn_dir, RETURN_P), "w+b"),
     )
 
     if "out" in load:
-        serial.dump(
+        salt.payload.dump(
             load["out"],
             # Use atomic open here to avoid the file being read before
             # it's completely written to. Refs #1935
@@ -198,7 +185,7 @@ def save_load(jid, clear_load, minions=None, recurse_count=0):
     as for salt-ssh)
     """
     if recurse_count >= 5:
-        err = "save_load could not write job cache file after {0} retries.".format(
+        err = "save_load could not write job cache file after {} retries.".format(
             recurse_count
         )
         log.error(err)
@@ -206,8 +193,6 @@ def save_load(jid, clear_load, minions=None, recurse_count=0):
 
     jid_dir = salt.utils.jid.jid_dir(jid, _job_dir(), __opts__["hash_type"])
 
-    serial = salt.payload.Serial(__opts__)
-
     # Save the invocation information
     try:
         if not os.path.exists(jid_dir):
@@ -221,8 +206,8 @@ def save_load(jid, clear_load, minions=None, recurse_count=0):
             raise
     try:
         with salt.utils.files.fopen(os.path.join(jid_dir, LOAD_P), "w+b") as wfh:
-            serial.dump(clear_load, wfh)
-    except IOError as exc:
+            salt.payload.dump(clear_load, wfh)
+    except OSError as exc:
         log.warning("Could not write job invocation cache file: %s", exc)
         time.sleep(0.1)
         return save_load(
@@ -252,10 +237,9 @@ def save_minions(jid, minions, syndic_id=None):
     log.debug(
         "Adding minions for job %s%s: %s",
         jid,
-        " from syndic master '{0}'".format(syndic_id) if syndic_id else "",
+        " from syndic master '{}'".format(syndic_id) if syndic_id else "",
         minions,
     )
-    serial = salt.payload.Serial(__opts__)
 
     jid_dir = salt.utils.jid.jid_dir(jid, _job_dir(), __opts__["hash_type"])
 
@@ -282,8 +266,8 @@ def save_minions(jid, minions, syndic_id=None):
             except OSError:
                 pass
         with salt.utils.files.fopen(minions_path, "w+b") as wfh:
-            serial.dump(minions, wfh)
-    except IOError as exc:
+            salt.payload.dump(minions, wfh)
+    except OSError as exc:
         log.error(
             "Failed to write minion list %s to job cache file %s: %s",
             minions,
@@ -300,14 +284,13 @@ def get_load(jid):
     load_fn = os.path.join(jid_dir, LOAD_P)
     if not os.path.exists(jid_dir) or not os.path.exists(load_fn):
         return {}
-    serial = salt.payload.Serial(__opts__)
     ret = {}
     load_p = os.path.join(jid_dir, LOAD_P)
     num_tries = 5
     for index in range(1, num_tries + 1):
         with salt.utils.files.fopen(load_p, "rb") as rfh:
             try:
-                ret = serial.load(rfh)
+                ret = salt.payload.load(rfh)
                 break
             except Exception as exc:  # pylint: disable=broad-except
                 if index == num_tries:
@@ -324,8 +307,8 @@ def get_load(jid):
         log.debug("Reading minion list from %s", minions_path)
         try:
             with salt.utils.files.fopen(minions_path, "rb") as rfh:
-                all_minions.update(serial.load(rfh))
-        except IOError as exc:
+                all_minions.update(salt.payload.load(rfh))
+        except OSError as exc:
             salt.utils.files.process_read_exception(exc, minions_path)
 
     if all_minions:
@@ -339,7 +322,6 @@ def get_jid(jid):
     Return the information returned when the specified job id was executed
     """
     jid_dir = salt.utils.jid.jid_dir(jid, _job_dir(), __opts__["hash_type"])
-    serial = salt.payload.Serial(__opts__)
 
     ret = {}
     # Check to see if the jid is real, if not return the empty dict
@@ -356,7 +338,7 @@ def get_jid(jid):
             while fn_ not in ret:
                 try:
                     with salt.utils.files.fopen(retp, "rb") as rfh:
-                        ret_data = serial.load(rfh)
+                        ret_data = salt.payload.load(rfh)
                     if not isinstance(ret_data, dict) or "return" not in ret_data:
                         # Convert the old format in which return.p contains the only return data to
                         # the new that is dict containing 'return' and optionally 'retcode' and
@@ -365,9 +347,9 @@ def get_jid(jid):
                     ret[fn_] = ret_data
                     if os.path.isfile(outp):
                         with salt.utils.files.fopen(outp, "rb") as rfh:
-                            ret[fn_]["out"] = serial.load(rfh)
+                            ret[fn_]["out"] = salt.payload.load(rfh)
                 except Exception as exc:  # pylint: disable=broad-except
-                    if "Permission denied:" in six.text_type(exc):
+                    if "Permission denied:" in str(exc):
                         raise
     return ret
 
@@ -411,11 +393,26 @@ def get_jids_filter(count, filter_find_job=True):
     return ret
 
 
+def _remove_job_dir(job_path):
+    """
+    Try to remove job dir. In rare cases NotADirectoryError can raise because node corruption.
+    :param job_path: Path to job
+    """
+    # Remove job dir
+    try:
+        shutil.rmtree(job_path)
+    except (NotADirectoryError, OSError) as err:
+        log.error("Unable to remove %s: %s", job_path, err)
+        return False
+    return True
+
+
 def clean_old_jobs():
     """
     Clean out the old jobs from the job cache
     """
-    if __opts__["keep_jobs"] != 0:
+    keep_jobs_seconds = salt.utils.job.get_keep_jobs_seconds(__opts__)
+    if keep_jobs_seconds != 0:
         jid_root = _job_dir()
 
         if not os.path.exists(jid_root):
@@ -442,18 +439,15 @@ def clean_old_jobs():
                 if not os.path.isfile(jid_file) and os.path.exists(f_path):
                     # No jid file means corrupted cache entry, scrub it
                     # by removing the entire f_path directory
-                    shutil.rmtree(f_path)
+                    _remove_job_dir(f_path)
                 elif os.path.isfile(jid_file):
                     jid_ctime = os.stat(jid_file).st_ctime
-                    hours_difference = (time.time() - jid_ctime) / 3600.0
-                    if hours_difference > __opts__["keep_jobs"] and os.path.exists(
+                    seconds_difference = time.time() - jid_ctime
+                    if seconds_difference > keep_jobs_seconds and os.path.exists(
                         t_path
                     ):
                         # Remove the entire f_path from the original JID dir
-                        try:
-                            shutil.rmtree(f_path)
-                        except OSError as err:
-                            log.error("Unable to remove %s: %s", f_path, err)
+                        _remove_job_dir(f_path)
 
         # Remove empty JID dirs from job cache, if they're old enough.
         # JID dirs may be empty either from a previous cache-clean with the bug
@@ -464,9 +458,9 @@ def clean_old_jobs():
                 # Checking the time again prevents a possible race condition where
                 # t_path JID dirs were created, but not yet populated by a jid file.
                 t_path_ctime = os.stat(t_path).st_ctime
-                hours_difference = (time.time() - t_path_ctime) / 3600.0
-                if hours_difference > __opts__["keep_jobs"]:
-                    shutil.rmtree(t_path)
+                seconds_difference = time.time() - t_path_ctime
+                if seconds_difference > keep_jobs_seconds:
+                    _remove_job_dir(t_path)
 
 
 def update_endtime(jid, time):
@@ -481,7 +475,7 @@ def update_endtime(jid, time):
             os.makedirs(jid_dir)
         with salt.utils.files.fopen(os.path.join(jid_dir, ENDTIME), "w") as etfile:
             etfile.write(salt.utils.stringutils.to_str(time))
-    except IOError as exc:
+    except OSError as exc:
         log.warning("Could not write job invocation cache file: %s", exc)
 
 
