@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Installation of Python Packages Using pip
 =========================================
@@ -19,18 +18,12 @@ requisite to a pkg.installed state for the package which provides pip
           - pkg: python-pip
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
 import logging
 import re
 import sys
 import types
 
-# Import 3rd-party libs
-import salt.ext.six as six
-
-# Import salt libs
 import salt.utils.data
 import salt.utils.versions
 from salt.exceptions import CommandExecutionError, CommandNotFoundError
@@ -76,7 +69,11 @@ def pip_has_internal_exceptions_mod(ver):
     """
     True when the pip version has the `pip._internal.exceptions` module
     """
-    return salt.utils.versions.compare(ver1=ver, oper=">=", ver2="10.0",)
+    return salt.utils.versions.compare(
+        ver1=ver,
+        oper=">=",
+        ver2="10.0",
+    )
 
 
 def pip_has_exceptions_mod(ver):
@@ -106,9 +103,9 @@ if HAS_PIP is True:
 
         purge_pip.__pip_ver__ = pip.__version__
     if salt.utils.versions.compare(ver1=pip.__version__, oper=">=", ver2="10.0"):
-        from pip._internal.exceptions import (
+        from pip._internal.exceptions import (  # pylint: disable=E0611,E0401
             InstallationError,
-        )  # pylint: disable=E0611,E0401
+        )
     elif salt.utils.versions.compare(ver1=pip.__version__, oper=">=", ver2="1.0"):
         from pip.exceptions import InstallationError  # pylint: disable=E0611,E0401
     else:
@@ -117,7 +114,7 @@ if HAS_PIP is True:
 
 # pylint: enable=import-error
 
-log = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 # Define the module's virtual name
 __virtualname__ = "pip"
@@ -177,7 +174,7 @@ def _check_pkg_version_format(pkg):
 
     if not HAS_PIP:
         ret["comment"] = (
-            "An importable Python 2 pip module is required but could not be "
+            "An importable Python pip module is required but could not be "
             "found on your system. This usually means that the system's pip "
             "package is not installed properly."
         )
@@ -192,16 +189,16 @@ def _check_pkg_version_format(pkg):
             # vcs+URL urls are not properly parsed.
             # The next line is meant to trigger an AttributeError and
             # handle lower pip versions
-            log.debug("Installed pip version: %s", pip.__version__)
+            logger.debug("Installed pip version: %s", pip.__version__)
             install_req = _from_line(pkg)
         except AttributeError:
-            log.debug("Installed pip version is lower than 1.2")
+            logger.debug("Installed pip version is lower than 1.2")
             supported_vcs = ("git", "svn", "hg", "bzr")
             if pkg.startswith(supported_vcs):
                 for vcs in supported_vcs:
                     if pkg.startswith(vcs):
                         from_vcs = True
-                        install_req = _from_line(pkg.split("{0}+".format(vcs))[-1])
+                        install_req = _from_line(pkg.split("{}+".format(vcs))[-1])
                         break
             else:
                 install_req = _from_line(pkg)
@@ -209,11 +206,11 @@ def _check_pkg_version_format(pkg):
         ret["result"] = False
         if not from_vcs and "=" in pkg and "==" not in pkg:
             ret["comment"] = (
-                "Invalid version specification in package {0}. '=' is "
+                "Invalid version specification in package {}. '=' is "
                 "not supported, use '==' instead.".format(pkg)
             )
             return ret
-        ret["comment"] = "pip raised an exception while parsing '{0}': {1}".format(
+        ret["comment"] = "pip raised an exception while parsing '{}': {}".format(
             pkg, exc
         )
         return ret
@@ -254,7 +251,7 @@ def _check_if_installed(
     index_url,
     extra_index_url,
     pip_list=False,
-    **kwargs
+    **kwargs,
 ):
     """
     Takes a package name and version specification (if any) and checks it is
@@ -291,7 +288,7 @@ def _check_if_installed(
                 and _fulfills_version_spec(pip_list[prefix], version_spec)
             ) or (not any(version_spec)):
                 ret["result"] = True
-                ret["comment"] = "Python package {0} was already " "installed".format(
+                ret["comment"] = "Python package {} was already installed".format(
                     state_pkg_name
                 )
                 return ret
@@ -320,17 +317,17 @@ def _check_if_installed(
                 extra_index_url=extra_index_url,
             )
             desired_version = ""
-            if any(version_spec):
+            if any(version_spec) and available_versions:
                 for version in reversed(available_versions):
                     if _fulfills_version_spec(version, version_spec):
                         desired_version = version
                         break
-            else:
+            elif available_versions:
                 desired_version = available_versions[-1]
             if not desired_version:
                 ret["result"] = True
                 ret["comment"] = (
-                    "Python package {0} was already "
+                    "Python package {} was already "
                     "installed and\nthe available upgrade "
                     "doesn't fulfills the version "
                     "requirements".format(prefix)
@@ -338,7 +335,7 @@ def _check_if_installed(
                 return ret
             if _pep440_version_cmp(pip_list[prefix], desired_version) == 0:
                 ret["result"] = True
-                ret["comment"] = "Python package {0} was already " "installed".format(
+                ret["comment"] = "Python package {} was already installed".format(
                     state_pkg_name
                 )
                 return ret
@@ -354,15 +351,11 @@ def _pep440_version_cmp(pkg1, pkg2, ignore_epoch=False):
     making the comparison.
     """
     if HAS_PKG_RESOURCES is False:
-        log.warning(
+        logger.warning(
             "The pkg_resources packages was not loaded. Please install setuptools."
         )
         return None
-    normalize = (
-        lambda x: six.text_type(x).split("!", 1)[-1]
-        if ignore_epoch
-        else six.text_type(x)
-    )
+    normalize = lambda x: str(x).split("!", 1)[-1] if ignore_epoch else str(x)
     pkg1 = normalize(pkg1)
     pkg2 = normalize(pkg2)
 
@@ -374,7 +367,9 @@ def _pep440_version_cmp(pkg1, pkg2, ignore_epoch=False):
         if pkg_resources.parse_version(pkg1) > pkg_resources.parse_version(pkg2):
             return 1
     except Exception as exc:  # pylint: disable=broad-except
-        log.exception(exc)
+        logger.exception(
+            f'Comparison of package versions "{pkg1}" and "{pkg2}" failed: {exc}'
+        )
     return None
 
 
@@ -425,7 +420,7 @@ def installed(
     cache_dir=None,
     no_binary=None,
     extra_args=None,
-    **kwargs
+    **kwargs,
 ):
     """
     Make sure the package is installed
@@ -572,11 +567,6 @@ def installed(
     process_dependency_links
         Enable the processing of dependency links
 
-    bin_env : None
-        Absolute path to a virtual environment directory or absolute path to
-        a pip executable. The example below assumes a virtual environment
-        has been created at ``/foo/.virtualenvs/bar``.
-
     env_vars
         Add or modify environment variables. Useful for tweaking build steps,
         such as specifying INCLUDE or LIBRARY paths in Makefiles, build scripts or
@@ -600,29 +590,34 @@ def installed(
         Mark this host as trusted, even though it does not have valid or any
         HTTPS.
 
-    Example:
+    bin_env : None
+        Absolute path to a virtual environment directory or absolute path to
+        a pip executable. The example below assumes a virtual environment
+        has been created at ``/foo/.virtualenvs/bar``.
 
-    .. code-block:: yaml
+        Example:
 
-        django:
-          pip.installed:
-            - name: django >= 1.6, <= 1.7
-            - bin_env: /foo/.virtualenvs/bar
-            - require:
-              - pkg: python-pip
+        .. code-block:: yaml
 
-    Or
+            django:
+            pip.installed:
+                - name: django >= 1.6, <= 1.7
+                - bin_env: /foo/.virtualenvs/bar
+                - require:
+                - pkg: python-pip
 
-    Example:
+        Or
 
-    .. code-block:: yaml
+        Example:
 
-        django:
-          pip.installed:
-            - name: django >= 1.6, <= 1.7
-            - bin_env: /foo/.virtualenvs/bar/bin/pip
-            - require:
-              - pkg: python-pip
+        .. code-block:: yaml
+
+            django:
+            pip.installed:
+                - name: django >= 1.6, <= 1.7
+                - bin_env: /foo/.virtualenvs/bar/bin/pip
+                - require:
+                - pkg: python-pip
 
     .. admonition:: Attention
 
@@ -706,6 +701,20 @@ def installed(
 
 
     .. _`virtualenv`: http://www.virtualenv.org/en/latest/
+
+    If you are using onedir packages and you need to install python packages into
+    the system python environment, you must provide the pip_bin or
+    bin_env to the pip state module.
+
+
+    .. code-block:: yaml
+
+        lib-foo:
+          pip.installed:
+            - pip_bin: /usr/bin/pip3
+        lib-bar:
+          pip.installed:
+            - bin_env: /usr/bin/python3
     """
     if pip_bin and not bin_env:
         bin_env = pip_bin
@@ -728,8 +737,8 @@ def installed(
     # pkgs = ','.join([prepro(pkg) for pkg in pkgs])
     prepro = (
         lambda pkg: pkg
-        if isinstance(pkg, six.string_types)
-        else " ".join((six.iteritems(pkg)[0][0], six.iteritems(pkg)[0][1]))
+        if isinstance(pkg, str)
+        else " ".join((pkg.items()[0][0], pkg.items()[0][1]))
     )
     pkgs = [prepro(pkg) for pkg in pkgs]
 
@@ -738,8 +747,8 @@ def installed(
     try:
         cur_version = __salt__["pip.version"](bin_env)
     except (CommandNotFoundError, CommandExecutionError) as err:
-        ret["result"] = None
-        ret["comment"] = "Error installing '{0}': {1}".format(name, err)
+        ret["result"] = False
+        ret["comment"] = "Error installing '{}': {}".format(name, err)
         return ret
     # Check that the pip binary supports the 'use_wheel' option
     if use_wheel:
@@ -755,9 +764,9 @@ def installed(
             ret["result"] = False
             ret["comment"] = (
                 "The 'use_wheel' option is only supported in "
-                "pip between {0} and {1}. The version of pip detected "
-                "was {2}."
-            ).format(min_version, max_version, cur_version)
+                "pip between {} and {}. The version of pip detected "
+                "was {}.".format(min_version, max_version, cur_version)
+            )
             return ret
 
     # Check that the pip binary supports the 'no_use_wheel' option
@@ -774,9 +783,9 @@ def installed(
             ret["result"] = False
             ret["comment"] = (
                 "The 'no_use_wheel' option is only supported in "
-                "pip between {0} and {1}. The version of pip detected "
-                "was {2}."
-            ).format(min_version, max_version, cur_version)
+                "pip between {} and {}. The version of pip detected "
+                "was {}.".format(min_version, max_version, cur_version)
+            )
             return ret
 
     # Check that the pip binary supports the 'no_binary' option
@@ -789,9 +798,9 @@ def installed(
             ret["result"] = False
             ret["comment"] = (
                 "The 'no_binary' option is only supported in "
-                "pip {0} and newer. The version of pip detected "
-                "was {1}."
-            ).format(min_version, cur_version)
+                "pip {} and newer. The version of pip detected "
+                "was {}.".format(min_version, cur_version)
+            )
             return ret
 
     # Get the packages parsed name and version from the pip library.
@@ -825,12 +834,12 @@ def installed(
                 # TODO: Check requirements file against currently-installed
                 # packages to provide more accurate state output.
                 comments.append(
-                    "Requirements file '{0}' will be " "processed.".format(requirements)
+                    "Requirements file '{}' will be processed.".format(requirements)
                 )
             if editable:
                 comments.append(
                     "Package will be installed in editable mode (i.e. "
-                    'setuptools "develop mode") from {0}.'.format(editable)
+                    'setuptools "develop mode") from {}.'.format(editable)
                 )
             ret["comment"] = " ".join(comments)
             return ret
@@ -838,12 +847,16 @@ def installed(
     # No requirements case.
     # Check pre-existence of the requested packages.
     else:
-        # Attempt to pre-cache a the current pip list
+        # Attempt to pre-cache the current pip list
         try:
-            pip_list = __salt__["pip.list"](bin_env=bin_env, user=user, cwd=cwd)
+            pip_list = __salt__["pip.list"](
+                bin_env=bin_env, user=user, cwd=cwd, env_vars=env_vars
+            )
         # If we fail, then just send False, and we'll try again in the next function call
         except Exception as exc:  # pylint: disable=broad-except
-            log.exception(exc)
+            logger.exception(
+                f"Pre-caching of PIP packages during states.pip.installed failed by exception from pip.list: {exc}"
+            )
             pip_list = False
 
         for prefix, state_pkg_name, version_spec in pkgs_details:
@@ -863,7 +876,7 @@ def installed(
                     index_url,
                     extra_index_url,
                     pip_list,
-                    **kwargs
+                    **kwargs,
                 )
                 # If _check_if_installed result is None, something went wrong with
                 # the command running. This way we keep stateful output.
@@ -925,7 +938,7 @@ def installed(
 
     # Call to install the package. Actual installation takes place here
     pip_install_call = __salt__["pip.install"](
-        pkgs="{0}".format(pkgs_str) if pkgs_str else "",
+        pkgs="{}".format(pkgs_str) if pkgs_str else "",
         requirements=requirements,
         bin_env=bin_env,
         use_wheel=use_wheel,
@@ -969,7 +982,7 @@ def installed(
         no_cache_dir=no_cache_dir,
         extra_args=extra_args,
         disable_version_check=True,
-        **kwargs
+        **kwargs,
     )
 
     if pip_install_call and pip_install_call.get("retcode", 1) == 0:
@@ -994,16 +1007,18 @@ def installed(
                         ret["changes"]["requirements"] = True
                 if ret["changes"].get("requirements"):
                     comments.append(
-                        "Successfully processed requirements file "
-                        "{0}.".format(requirements)
+                        "Successfully processed requirements file {}.".format(
+                            requirements
+                        )
                     )
                 else:
                     comments.append("Requirements were already installed.")
 
             if editable:
                 comments.append(
-                    "Package successfully installed from VCS "
-                    "checkout {0}.".format(editable)
+                    "Package successfully installed from VCS checkout {}.".format(
+                        editable
+                    )
                 )
                 ret["changes"]["editable"] = True
             ret["comment"] = " ".join(comments)
@@ -1032,7 +1047,7 @@ def installed(
                             user=user,
                             cwd=cwd,
                             env_vars=env_vars,
-                            **kwargs
+                            **kwargs,
                         )
                     )
 
@@ -1040,7 +1055,7 @@ def installed(
                     # installing it report it
                     if not pipsearch:
                         pkg_404_comms.append(
-                            "There was no error installing package '{0}' "
+                            "There was no error installing package '{}' "
                             "although it does not show when calling "
                             "'pip.freeze'.".format(pkg)
                         )
@@ -1050,10 +1065,10 @@ def installed(
                             and prefix.lower() not in already_installed_packages
                         ):
                             ver = pipsearch[prefix]
-                            ret["changes"]["{0}=={1}".format(prefix, ver)] = "Installed"
+                            ret["changes"]["{}=={}".format(prefix, ver)] = "Installed"
                 # Case for packages that are an URL
                 else:
-                    ret["changes"]["{0}==???".format(state_name)] = "Installed"
+                    ret["changes"]["{}==???".format(state_name)] = "Installed"
 
             # Set comments
             aicomms = "\n".join(already_installed_comments)
@@ -1069,30 +1084,28 @@ def installed(
     elif pip_install_call:
         ret["result"] = False
         if "stdout" in pip_install_call:
-            error = "Error: {0} {1}".format(
+            error = "Error: {} {}".format(
                 pip_install_call["stdout"], pip_install_call["stderr"]
             )
         else:
-            error = "Error: {0}".format(pip_install_call["comment"])
+            error = "Error: {}".format(pip_install_call["comment"])
 
         if requirements or editable:
             comments = []
             if requirements:
                 comments.append(
-                    "Unable to process requirements file " '"{0}".'.format(requirements)
+                    'Unable to process requirements file "{}"'.format(requirements)
                 )
             if editable:
                 comments.append(
-                    "Unable to install from VCS checkout" "{0}.".format(editable)
+                    "Unable to install from VCS checkout {}.".format(editable)
                 )
             comments.append(error)
             ret["comment"] = " ".join(comments)
         else:
             pkgs_str = ", ".join([state_name for _, state_name in target_pkgs])
             aicomms = "\n".join(already_installed_comments)
-            error_comm = "Failed to install packages: {0}. " "{1}".format(
-                pkgs_str, error
-            )
+            error_comm = "Failed to install packages: {}. {}".format(pkgs_str, error)
             ret["comment"] = aicomms + ("\n" if aicomms else "") + error_comm
     else:
         ret["result"] = False
@@ -1130,7 +1143,7 @@ def removed(
         pip_list = __salt__["pip.list"](bin_env=bin_env, user=user, cwd=cwd)
     except (CommandExecutionError, CommandNotFoundError) as err:
         ret["result"] = False
-        ret["comment"] = "Error uninstalling '{0}': {1}".format(name, err)
+        ret["comment"] = "Error uninstalling '{}': {}".format(name, err)
         return ret
 
     if name not in pip_list:
@@ -1140,7 +1153,7 @@ def removed(
 
     if __opts__["test"]:
         ret["result"] = None
-        ret["comment"] = "Package {0} is set to be removed".format(name)
+        ret["comment"] = "Package {} is set to be removed".format(name)
         return ret
 
     if __salt__["pip.uninstall"](
@@ -1184,7 +1197,7 @@ def uptodate(name, bin_env=None, user=None, cwd=None, use_vt=False):
     try:
         packages = __salt__["pip.list_upgrades"](bin_env=bin_env, user=user, cwd=cwd)
     except Exception as e:  # pylint: disable=broad-except
-        ret["comment"] = six.text_type(e)
+        ret["comment"] = str(e)
         return ret
 
     if not packages:
